==> qtbase6.7-static-6.7.2-3.1-x86_64.pkg.tar.zst: opt/qt6.7-static/include/QtGui/qtgui-config.h <==
#define QT_FEATURE_accessibility_atspi_bridge -1

#define QT_FEATURE_freetype 1

#define QT_FEATURE_fontconfig 1

#define QT_FEATURE_harfbuzz 1

#define QT_FEATURE_opengles2 -1

#define QT_FEATURE_opengles3 -1

#define QT_FEATURE_opengles31 -1

#define QT_FEATURE_opengles32 -1

#define QT_FEATURE_dynamicgl -1

#define QT_FEATURE_opengl 1

#define QT_FEATURE_vulkan -1

#define QT_FEATURE_openvg -1

#define QT_FEATURE_egl 1

#define QT_FEATURE_ico -1

#define QT_FEATURE_sessionmanager 1

#define QT_FEATURE_xcb 1

#define QT_FEATURE_xcb_glx_plugin 1

#define QT_FEATURE_texthtmlparser 1

#define QT_FEATURE_textmarkdownreader 1

#define QT_FEATURE_system_textmarkdownreader -1

#define QT_FEATURE_textmarkdownwriter 1

#define QT_FEATURE_textodfwriter 1

#define QT_FEATURE_cssparser 1

#define QT_FEATURE_draganddrop 1

#define QT_FEATURE_action 1

#define QT_FEATURE_cursor 1

#define QT_FEATURE_clipboard 1

#define QT_FEATURE_wheelevent 1

#define QT_FEATURE_tabletevent 1

#define QT_FEATURE_im 1

#define QT_FEATURE_highdpiscaling 1

#define QT_FEATURE_validator 1

#define QT_FEATURE_standarditemmodel 1

#define QT_FEATURE_filesystemmodel 1

#define QT_FEATURE_imageformatplugin 1

#define QT_FEATURE_movie 1

#define QT_FEATURE_imageformat_bmp 1

#define QT_FEATURE_imageformat_ppm 1

#define QT_FEATURE_imageformat_xbm 1

#define QT_FEATURE_imageformat_xpm 1

#define QT_FEATURE_imageformat_png 1

#define QT_FEATURE_imageformat_jpeg 1

#define QT_FEATURE_image_heuristic_mask 1

#define QT_FEATURE_image_text 1

#define QT_FEATURE_picture 1

#define QT_FEATURE_colornames 1

#define QT_FEATURE_pdf 1

#define QT_FEATURE_desktopservices 1

#define QT_FEATURE_systemtrayicon 1

#define QT_FEATURE_accessibility 1

#define QT_FEATURE_whatsthis 1

#define QT_FEATURE_undocommand 1

#define QT_FEATURE_undostack 1

#define QT_FEATURE_undogroup 1

#define QT_FEATURE_wayland 1

#define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE 1
#define QT_NO_IMAGEFORMAT_GIF
#define QT_NO_ICO 1

==> qtbase6.8-static-6.8.1-2.2-x86_64.pkg.tar.zst: opt/qt6.8-static/include/QtGui/qtgui-config.h <==
#define QT_FEATURE_accessibility_atspi_bridge -1

#define QT_FEATURE_freetype 1

#define QT_FEATURE_fontconfig 1

#define QT_FEATURE_harfbuzz 1

#define QT_FEATURE_opengles2 -1

#define QT_FEATURE_opengles3 -1

#define QT_FEATURE_opengles31 -1

#define QT_FEATURE_opengles32 -1

#define QT_FEATURE_dynamicgl -1

#define QT_FEATURE_opengl -1

#define QT_FEATURE_vulkan -1

#define QT_FEATURE_metal -1

#define QT_FEATURE_openvg -1

#define QT_FEATURE_egl -1

#define QT_FEATURE_ico -1

#define QT_FEATURE_sessionmanager 1

#define QT_FEATURE_xcb 1

#define QT_FEATURE_xcb_glx_plugin -1

#define QT_FEATURE_texthtmlparser 1

#define QT_FEATURE_textmarkdownreader 1

#define QT_FEATURE_system_textmarkdownreader -1

#define QT_FEATURE_textmarkdownwriter 1

#define QT_FEATURE_textodfwriter 1

#define QT_FEATURE_cssparser 1

#define QT_FEATURE_draganddrop 1

#define QT_FEATURE_action 1

#define QT_FEATURE_cursor 1

#define QT_FEATURE_clipboard 1

#define QT_FEATURE_wheelevent 1

#define QT_FEATURE_tabletevent 1

#define QT_FEATURE_im 1

#define QT_FEATURE_highdpiscaling 1

#define QT_FEATURE_validator 1

#define QT_FEATURE_standarditemmodel 1

#define QT_FEATURE_filesystemmodel 1

#define QT_FEATURE_imageformatplugin 1

#define QT_FEATURE_movie 1

#define QT_FEATURE_imageformat_bmp 1

#define QT_FEATURE_imageformat_ppm 1

#define QT_FEATURE_imageformat_xbm 1

#define QT_FEATURE_imageformat_xpm 1

#define QT_FEATURE_imageformat_png 1

#define QT_FEATURE_imageformat_jpeg 1

#define QT_FEATURE_image_heuristic_mask 1

#define QT_FEATURE_image_text 1

#define QT_FEATURE_picture 1

#define QT_FEATURE_colornames 1

#define QT_FEATURE_pdf 1

#define QT_FEATURE_desktopservices 1

#define QT_FEATURE_systemtrayicon 1

#define QT_FEATURE_accessibility 1

#define QT_FEATURE_whatsthis 1

#define QT_FEATURE_undocommand 1

#define QT_FEATURE_undostack 1

#define QT_FEATURE_undogroup 1

#define QT_FEATURE_wayland 1

#define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE 1
#define QT_NO_OPENGL 1
#define QT_NO_EGL 1
#define QT_NO_IMAGEFORMAT_GIF
#define QT_NO_ICO 1
